/**
  *  \file server/serverio.cc
  *  \brief Server: I/O primitives
  *
  *  This module provides simple primitives for the other modules to
  *  use for communicating with the client. This allows easy
  *  replacement for environments where stdio doesn't work for us.
  */

#include <iostream>
#include "server/serverio.h"

uint32_t bytesRead, bytesWritten;

/** Write reply to client. */
void
writeClient(string_t line)
{
    bytesWritten += line.size()+1;
    std::cout << line << "\n";
}

/** Write message terminator to client. */
void
writeClientTerminator()
{
    bytesWritten += 2;
    std::cout << ".\n";
}

/** Read command from client.  */
bool
readClient(string_t& line)
{
    std::cout.flush();
    if (!std::cout.good())
        return false;
    if (getline(std::cin, line)) {
        bytesRead += line.size()+1;
        return true;
    } else {
        return false;
    }
}

void
ServerJsonWriter::writeLine(const string_t& line)
{
    writeClient(line);
}
